@@ -102,6 +102,7 @@ SEXP processx_write(SEXP fd, SEXP data) {
 #include <fcntl.h>
 #include <errno.h>
 #include <unistd.h>
+#include <stdlib.h>
 
 #include <R_ext/Rdynload.h>
 #include <Rinternals.h>
@@ -125,13 +126,18 @@ static int processx__cloexec_fcntl(int fd, int set) {
   return 0;
 }
 
-SEXP processx_disable_inheritance() {
+SEXP processx_disable_inheritance(void) {
   int fd;
 
   /* Set the CLOEXEC flag on all open descriptors. Unconditionally try the
    * first 16 file descriptors. After that, bail out after the first error.
-   */
-  for (fd = 0; ; fd++) {
+   * We skip the standard streams, because R and `system()` is not prepared
+   * to not inheriting stdin and eg. an R subprocess does not even start in
+   * system(). See https://github.com/r-lib/callr/issues/236. */
+
+  int firstfd = 3;
+  if (getenv("PROCESSX_CLOEXEC_STDIO")) firstfd = 0;
+  for (fd = firstfd; ; fd++) {
     if (processx__cloexec_fcntl(fd, 1) && fd > 15) break;
   }
 
@@ -228,6 +234,34 @@ SEXP processx_set_stderr_to_file(SEXP file) {
 SEXP processx_base64_encode(SEXP array);
 SEXP processx_base64_decode(SEXP array);
 
+
+#ifndef _WIN32
+
+#include <string.h>
+#include <signal.h>
+
+void term_handler(int n) {
+  // Need the cast and the +1 to ignore compiler warning about unused
+  // return value.
+  (void) (system("rm -rf \"$R_SESSION_TMPDIR\"") + 1);
+  // Continue signal
+  raise(SIGTERM);
+}
+
+void install_term_handler(void) {
+  if (! getenv("PROCESSX_R_SIGTERM_CLEANUP")) {
+    return;
+  }
+
+  struct sigaction sig = {{ 0 }};
+  sig.sa_handler = term_handler;
+  sig.sa_flags = SA_RESETHAND;
+  sigaction(SIGTERM, &sig, NULL);
+}
+
+#endif // not _WIN32
+
+
 static const R_CallMethodDef callMethods[]  = {
   { "processx_base64_encode", (DL_FUNC) &processx_base64_encode, 1 },
   { "processx_base64_decode", (DL_FUNC) &processx_base64_decode, 1 },
@@ -244,4 +278,8 @@ void R_init_client(DllInfo *dll) {
   R_registerRoutines(dll, NULL, callMethods, NULL, NULL);
   R_useDynamicSymbols(dll, FALSE);
   R_forceSymbols(dll, TRUE);
+
+#ifndef _WIN32
+  install_term_handler();
+#endif
 }
